@@ -1,4 +1,6 @@
+import gc
 import io
+import multiprocessing
 import warnings
 from contextlib import ExitStack
 from pathlib import Path
@@ -64,10 +66,10 @@ def test_mp4_writing(tmp_path, test_images):
         frames,
         extension=".mp4",
         plugin="pyav",
-        codec="libx264",
+        codec="h264",
     )
 
-    # libx264 writing is not deterministic and RGB -> YUV is lossy
+    # h264 writing is not deterministic and RGB -> YUV is lossy
     # so I have no good ideas how to do serious assertions on the file
     assert mp4_bytes is not None
 
@@ -131,22 +133,23 @@ def test_video_format_to_dtype():
     # they have no components. Therefore we can't deduce an appropriate dtype
     # from these so we have to raise instead.
     fake_formats = [
-        "vdpau",
-        "dxva2_vld",
-        "vaapi_moco",
-        "drm_prime",
-        "mediacodec",
-        "qsv",
-        "mmal",
-        "vulkan",
-        "vaapi_vld",
+        "cuda",
         "d3d11",
         "d3d11va_vld",
-        "videotoolbox_vld",
-        "vaapi",
-        "vaapi_idct",
+        "d3d12",
+        "drm_prime",
+        "dxva2_vld",
+        "mediacodec",
+        "mmal",
         "opencl",
-        "cuda",
+        "qsv",
+        "vaapi_idct",
+        "vaapi_moco",
+        "vaapi_vld",
+        "vaapi",
+        "vdpau",
+        "videotoolbox_vld",
+        "vulkan",
         "xvmc",
     ]
 
@@ -221,7 +224,7 @@ def test_write_bytes(test_images):
         img,
         extension=".mp4",
         plugin="pyav",
-        codec="libx264",
+        codec="h264",
     )
 
     assert img_bytes is not None
@@ -351,7 +354,7 @@ def test_multiple_writes(test_images):
             plugin="pyav",
             format="rgba",
         ):
-            file.write(frame, is_batch=False, codec="libx264", in_pixel_format="rgba")
+            file.write(frame, is_batch=False, codec="h264", in_pixel_format="rgba")
 
     actual = out_buffer.getvalue()
     assert actual is not None
@@ -506,7 +509,7 @@ def test_procedual_writing_with_filter(test_images):
 
 def test_rotation_flag_metadata(test_images, tmp_path):
     with iio.imopen(tmp_path / "test.mp4", "w", plugin="pyav") as file:
-        file.init_video_stream("libx264")
+        file.init_video_stream("h264")
         file.container_metadata["comment"] = "This video has a rotation flag."
         file.video_stream_metadata["rotate"] = "90"
 
@@ -552,7 +555,7 @@ def test_keyframe_intervals(test_images):
         )
 
         out_file.init_video_stream(
-            "libx264", max_keyframe_interval=5, force_keyframes=True
+            "h264", max_keyframe_interval=5, force_keyframes=True
         )
 
         for idx in range(50):
@@ -565,10 +568,10 @@ def test_keyframe_intervals(test_images):
     with iio.imopen(buffer, "r", plugin="pyav") as file:
         n_frames = file.properties().shape[0]
         for idx in range(1, n_frames):
-            medatada = file.metadata(index=idx)
-            if medatada["frame_type"] == "I":
+            metatada = file.metadata(index=idx)
+            if metatada["frame_type"] == "I":
                 i_dist.append(idx)
-            if medatada["key_frame"]:
+            if metatada["key_frame"]:
                 key_dist.append(idx)
 
     assert np.max(np.diff(i_dist)) <= 5
@@ -585,3 +588,32 @@ def test_trim_filter(test_images):
     )
 
     assert frames.shape == (20, 720, 1280, 3)
+
+
+def subprocess(func, conn):
+    try:
+        result = func()
+        conn.send(result)
+    except BaseException as e:
+        conn.send(e)
+
+
+def test_lagging_video_stream(test_images):
+    # this is a regression test
+    # see: https://github.com/imageio/imageio/issues/1095
+
+    with iio.imopen(
+        test_images / "cockatoo.mp4",
+        "r",
+        plugin="pyav",
+    ) as img_file:
+        for idx in range(50):
+            img_file.read(index=idx)
+
+    output, input = multiprocessing.Pipe()
+    proc = multiprocessing.Process(target=subprocess, args=(gc.collect, input))
+
+    proc.start()
+    if not output.poll(timeout=5):
+        proc.kill()
+        raise TimeoutError("Test Subprocess failed to respond in time.")
